@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -122,7 +122,7 @@ except ImportError:
 
 
 # Iris revision.
-__version__ = '1.11.0'
+__version__ = '1.12.0'
 
 # Restrict the names imported when using "from iris import *"
 __all__ = ['load', 'load_cube', 'load_cubes', 'load_raw',
@@ -446,7 +446,9 @@ def load_raw(uris, constraints=None, callback=None):
         An :class:`iris.cube.CubeList`.
 
     """
-    return _load_collection(uris, constraints, callback).cubes()
+    from iris.fileformats.um._fast_load import _raw_structured_loading
+    with _raw_structured_loading():
+        return _load_collection(uris, constraints, callback).cubes()
 
 
 save = iris.io.save
