@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -69,7 +69,7 @@ __all__ = ('COUNT', 'GMEAN', 'HMEAN', 'MAX', 'MEAN', 'MEDIAN', 'MIN',
            'PEAK', 'PERCENTILE', 'PROPORTION', 'RMS', 'STD_DEV', 'SUM',
            'VARIANCE', 'WPERCENTILE', 'coord_comparison', 'Aggregator',
            'WeightedAggregator', 'clear_phenomenon_identity', 'Linear',
-           'AreaWeighted', 'Nearest')
+           'AreaWeighted', 'Nearest', 'UnstructuredNearest')
 
 
 class _CoordGroup(object):
@@ -2165,16 +2165,17 @@ class Linear(object):
 
 class AreaWeighted(object):
     """
-    This class describes the area-weighted regridding scheme for regridding
-    over one or more orthogonal coordinates, typically for use with
-    :meth:`iris.cube.Cube.regrid()`.
+    This class describes an area-weighted regridding scheme for regridding
+    between 'ordinary' horizontal grids with separated X and Y coordinates in a
+    common coordinate system.
+    Typically for use with :meth:`iris.cube.Cube.regrid()`.
 
     """
 
     def __init__(self, mdtol=1):
         """
-        Area-weighted regridding scheme suitable for regridding one or more
-        orthogonal coordinates.
+        Area-weighted regridding scheme suitable for regridding between
+        different orthogonal XY grids in the same coordinate system.
 
         Kwargs:
 
@@ -2187,6 +2188,12 @@ class AreaWeighted(object):
             will be masked if and only if all the overlapping elements of the
             source grid are masked. Defaults to 1.
 
+        .. Note:
+            Both sourge and target cubes must have an XY grid defined by
+            separate X and Y dimensions with dimension coordinates.
+            All of the XY dimension coordinates must also be bounded, and have
+            the same cooordinate system.
+
         """
         if not (0 <= mdtol <= 1):
             msg = 'Value for mdtol must be in range 0 - 1, got {}.'
@@ -2338,6 +2345,98 @@ class Nearest(object):
         return RectilinearRegridder(src_grid, target_grid, 'nearest',
                                     self.extrapolation_mode)
 
+
+class UnstructuredNearest(object):
+    """
+    This is a nearest-neighbour regridding scheme for regridding data whose
+    horizontal (X- and Y-axis) coordinates are mapped to the *same* dimensions,
+    rather than being orthogonal on independent dimensions.
+
+    For latitude-longitude coordinates, the nearest-neighbour distances are
+    computed on the sphere, otherwise flat Euclidean distances are used.
+
+    The source X and Y coordinates can have any shape.
+
+    The target grid must be of the "normal" kind, i.e. it has separate,
+    1-dimensional X and Y coordinates.
+
+    Source and target XY coordinates must have the same coordinate system,
+    which may also be None.
+    If any of the XY coordinates are latitudes or longitudes, then they *all*
+    must be.  Otherwise, the corresponding X and Y coordinates must have the
+    same units in the source and grid cubes.
+
+    .. Note::
+        Currently only supports regridding, not interpolation.
+
+    .. Note::
+          This scheme performs essentially the same job as
+          :class:`iris.experimental.regrid.ProjectedUnstructuredNearest`.
+          That scheme is faster, but only works well on data in a limited
+          region of the globe, covered by a specified projection.
+          This approach is more rigorously correct and can be applied to global
+          datasets.
+
+    """
+    # Note: the argument requirements are simply those of the underlying
+    # regridder class,
+    # :class:`iris.analysis.trajectory.UnstructuredNearestNeigbourRegridder`.
+    def __init__(self):
+        """
+        Nearest-neighbour interpolation and regridding scheme suitable for
+        interpolating or regridding from un-gridded data such as trajectories
+        or other data where the X and Y coordinates share the same dimensions.
+
+        """
+        pass
+
+    def __repr__(self):
+        return 'UnstructuredNearest()'
+
+    # TODO: add interpolator usage
+    # def interpolator(self, cube):
+
+    def regridder(self, src_cube, target_grid):
+        """
+        Creates a nearest-neighbour regridder, of the
+        :class:`~iris.analysis.trajectory.UnstructuredNearestNeigbourRegridder`
+        type, to perform regridding from the source grid to the target grid.
+
+        This can then be applied to any source data with the same structure as
+        the original 'src_cube'.
+
+        Typically you should use :meth:`iris.cube.Cube.regrid` for
+        regridding a cube. There are, however, some situations when
+        constructing your own regridder is preferable. These are detailed in
+        the :ref:`user guide <caching_a_regridder>`.
+
+        Args:
+
+        * src_cube:
+            The :class:`~iris.cube.Cube` defining the source grid.
+            The X and Y coordinates can have any shape, but must be mapped over
+            the same cube dimensions.
+
+        * target_grid:
+            The :class:`~iris.cube.Cube` defining the target grid.
+            The X and Y coordinates must be one-dimensional dimension
+            coordinates, mapped to different dimensions.
+            All other cube components are ignored.
+
+        Returns:
+            A callable with the interface:
+
+                `callable(cube)`
+
+            where `cube` is a cube with the same grid as `src_cube`
+            that is to be regridded to the `target_grid`.
+
+        """
+        from iris.analysis.trajectory import \
+            UnstructuredNearestNeigbourRegridder
+        return UnstructuredNearestNeigbourRegridder(src_cube, target_grid)
+
+
 # Import "iris.analysis.interpolate" to replicate older automatic imports.
 # NOTE: do this at end, as otherwise its import of 'Linear' will fail.
 from . import _interpolate_backdoor as interpolate
