@@ -193,52 +193,65 @@ def nearest_neighbour_indices(cube, sample_points):
     return tuple(indices)
 
 
-def _nearest_neighbour_indices_ndcoords(cube, sample_point, cache=None):
+def _nearest_neighbour_indices_ndcoords(cube, sample_points, cache=None):
     """
     See documentation for :func:`iris.analysis.interpolate.nearest_neighbour_indices`.
 
+    'sample_points' is of the form [[coord-or-coord-name, point-value(s)]*].
+    The lengths of all the point-values sequences must be equal.
+
     This function is adapted for points sampling a multi-dimensional coord,
     and can currently only do nearest neighbour interpolation.
 
     Because this function can be slow for multidimensional coordinates,
     a 'cache' dictionary can be provided by the calling code.
 
+    .. Note::
+
+        If the points are longitudes/latitudes, these are handled correctly as
+        points on the sphere, but the values must be in 'degrees'.
+
     """
 
     # Developer notes:
     # A "sample space cube" is made which only has the coords and dims we are sampling on.
     # We get the nearest neighbour using this sample space cube.
 
-    if isinstance(sample_point, dict):
+    if isinstance(sample_points, dict):
         msg = ('Providing a dictionary to specify points is deprecated. '
                'Please provide a list of (coordinate, values) pairs.')
         warn_deprecated(msg)
-        sample_point = list(sample_point.items())
+        sample_points = list(sample_points.items())
 
-    if sample_point:
+    if sample_points:
         try:
-            coord, value = sample_point[0]
+            coord, value = sample_points[0]
         except ValueError:
-            raise ValueError('Sample points must be a list of (coordinate, value) pairs. Got %r.' % sample_point)
+            raise ValueError('Sample points must be a list of (coordinate, value) pairs. Got %r.' % sample_points)
 
     # Convert names to coords in sample_point
-    point = []
+    # Reformat sample point values for use in _cartesian_sample_points(), below.
+    coord_values = []
+    sample_point_coords = []
+    sample_point_coord_names = []
     ok_coord_ids = set(map(id, cube.dim_coords + cube.aux_coords))
-    for coord, value in sample_point:
-        if isinstance(coord, six.string_types):
-            coord = cube.coord(coord)
-        else:
-            coord = cube.coord(coord)
+    for coord, value in sample_points:
+        coord = cube.coord(coord)
         if id(coord) not in ok_coord_ids:
             msg = ('Invalid sample coordinate {!r}: derived coordinates are'
                    ' not allowed.'.format(coord.name()))
             raise ValueError(msg)
-        point.append((coord, value))
+        sample_point_coords.append(coord)
+        sample_point_coord_names.append(coord.name())
+        value = np.array(value, ndmin=1)
+        coord_values.append(value)
 
-    # Reformat sample_point for use in _cartesian_sample_points(), below.
-    sample_point = np.array([[value] for coord, value in point])
-    sample_point_coords = [coord for coord, value in point]
-    sample_point_coord_names = [coord.name() for coord, value in point]
+    coord_point_lens = np.array([len(value) for value in coord_values])
+    if not np.all(coord_point_lens == coord_point_lens[0]):
+        msg = 'All coordinates must have the same number of sample points.'
+        raise ValueError(msg)
+
+    coord_values = np.array(coord_values)
 
     # Which dims are we sampling?
     sample_dims = set()
@@ -262,14 +275,9 @@ def _nearest_neighbour_indices_ndcoords(cube, sample_point, cache=None):
     # Order the sample point coords according to the sample space cube coords
     sample_space_coord_names = [coord.name() for coord in sample_space_cube.coords()]
     new_order = [sample_space_coord_names.index(name) for name in sample_point_coord_names]
-    sample_point = np.array([sample_point[i] for i in new_order])
+    coord_values = np.array([coord_values[i] for i in new_order])
     sample_point_coord_names = [sample_point_coord_names[i] for i in new_order]
 
-    # Convert the sample point to cartesian coords.
-    # If there is no latlon within the coordinate there will be no change.
-    # Otherwise, geographic latlon is replaced with cartesian xyz.
-    cartesian_sample_point = _cartesian_sample_points(sample_point, sample_point_coord_names)[0]
-
     sample_space_coords = sample_space_cube.dim_coords + sample_space_cube.aux_coords
     sample_space_coords_and_dims = [(coord, sample_space_cube.coord_dims(coord)) for coord in sample_space_coords]
 
@@ -288,29 +296,53 @@ def _nearest_neighbour_indices_ndcoords(cube, sample_point, cache=None):
         # Convert to cartesian coordinates. Flatten for kdtree compatibility.
         cartesian_space_data_coords = _cartesian_sample_points(sample_space_data_positions, sample_point_coord_names)
 
-        # Get the nearest datum index to the sample point. This is the goal of the function.
+        # Create a kdtree for the nearest-distance lookup to these 3d points.
         kdtree = scipy.spatial.cKDTree(cartesian_space_data_coords)
-
-    cartesian_distance, datum_index = kdtree.query(cartesian_sample_point)
-    sample_space_ndi = np.unravel_index(datum_index, sample_space_cube.data.shape)
-
-    # Turn sample_space_ndi into a main cube slice.
-    # Map sample cube to main cube dims and leave the rest as a full slice.
-    main_cube_slice = [slice(None, None)] * cube.ndim
-    for sample_coord, sample_coord_dims in sample_space_coords_and_dims:
-        # Find the coord in the main cube
-        main_coord = cube.coord(sample_coord.name())
-        main_coord_dims = cube.coord_dims(main_coord)
-        # Mark the nearest data index/indices with respect to this coord
-        for sample_i, main_i in zip(sample_coord_dims, main_coord_dims):
-            main_cube_slice[main_i] = sample_space_ndi[sample_i]
-
+        # This can find the nearest datum point to any given target point,
+        # which is the goal of this function.
 
     # Update cache
     if cache is not None:
         cache[cube] = kdtree
 
-    return tuple(main_cube_slice)
+    # Convert the sample points to cartesian (3d) coords.
+    # If there is no latlon within the coordinate there will be no change.
+    # Otherwise, geographic latlon is replaced with cartesian xyz.
+    cartesian_sample_points = _cartesian_sample_points(
+        coord_values, sample_point_coord_names)
+
+    # Use kdtree to get the nearest sourcepoint index for each target point.
+    _, datum_index_lists = kdtree.query(cartesian_sample_points)
+
+    # Convert flat indices back into multidimensional sample-space indices.
+    sample_space_dimension_indices = np.unravel_index(
+        datum_index_lists, sample_space_cube.data.shape)
+    # Convert this from "pointwise list of index arrays for each dimension",
+    # to "list of cube indices for each point".
+    sample_space_ndis = np.array(sample_space_dimension_indices).transpose()
+
+    # For the returned result, we must convert these indices into the source
+    # (sample-space) cube, to equivalent indices into the target 'cube'.
+
+    # Make a result array: (cube.ndim * <index>), per sample point.
+    n_points = coord_values.shape[-1]
+    main_cube_slices = np.empty((n_points, cube.ndim), dtype=object)
+    # Initialise so all unused indices are ":".
+    main_cube_slices[:] = slice(None)
+
+    # Move result indices according to the source (sample) and target (cube)
+    # dimension mappings.
+    for sample_coord, sample_coord_dims in sample_space_coords_and_dims:
+        # Find the coord in the main cube
+        main_coord = cube.coord(sample_coord.name())
+        main_coord_dims = cube.coord_dims(main_coord)
+        # Fill nearest-point data indices for each coord dimension.
+        for sample_i, main_i in zip(sample_coord_dims, main_coord_dims):
+            main_cube_slices[:, main_i] = sample_space_ndis[:, sample_i]
+
+    # Return as a list of **tuples** : required for correct indexing usage.
+    result = [tuple(inds) for inds in main_cube_slices]
+    return result
 
 
 def extract_nearest_neighbour(cube, sample_points):
@@ -465,7 +497,7 @@ def regrid(source_cube, grid_cube, mode='bilinear', **kwargs):
 
     """
     if mode == 'bilinear':
-        scheme = iris.analysis.Linear(**kwargs)
+        scheme = Linear(**kwargs)
         return source_cube.regrid(grid_cube, scheme)
 
     # Condition 1
