@@ -126,14 +126,41 @@ def get_xy_dim_coords(cube):
         A tuple containing the cube's x and y dimension coordinates.
 
     """
-    x_coords = cube.coords(axis='x', dim_coords=True)
-    if len(x_coords) != 1:
+    return get_xy_coords(cube, dim_coords=True)
+
+
+def get_xy_coords(cube, dim_coords=False):
+    """
+    Return the x and y coordinates from a cube.
+
+    This function raises a ValueError if the cube does not contain one and
+    only one set of x and y coordinates. It also raises a ValueError
+    if the identified x and y coordinates do not have coordinate systems that
+    are equal.
+
+    Args:
+
+    * cube:
+        An instance of :class:`iris.cube.Cube`.
+
+    Kwargs:
+
+    * dim_coords:
+        Set this to True to only return dimension coordinates. Defaults to
+        False.
+
+    Returns:
+        A tuple containing the cube's x and y dimension coordinates.
+
+    """
+    x_coords = cube.coords(axis='x', dim_coords=dim_coords)
+    if len(x_coords) != 1 or x_coords[0].ndim != 1:
         raise ValueError('Cube {!r} must contain a single 1D x '
                          'coordinate.'.format(cube.name()))
     x_coord = x_coords[0]
 
-    y_coords = cube.coords(axis='y', dim_coords=True)
-    if len(y_coords) != 1:
+    y_coords = cube.coords(axis='y', dim_coords=dim_coords)
+    if len(y_coords) != 1 or y_coords[0].ndim != 1:
         raise ValueError('Cube {!r} must contain a single 1D y '
                          'coordinate.'.format(cube.name()))
     y_coord = y_coords[0]
