@@ -964,7 +964,8 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
         if np.issubdtype(self.dtype, np.str):
             # Collapse the coordinate by serializing the points and
             # bounds as strings.
-            serialize = lambda x: '|'.join([str(i) for i in x.flatten()])
+            def serialize(x):
+                return '|'.join([str(i) for i in x.flatten()])
             bounds = None
             string_type_fmt = 'S{}' if six.PY2 else 'U{}'
             if self.bounds is not None:
@@ -1168,6 +1169,14 @@ class Coord(six.with_metaclass(ABCMeta, CFVariableMixin)):
 
         Only works for one-dimensional coordinates.
 
+        For example:
+
+        >>> cube = iris.load_cube(iris.sample_data_path('ostia_monthly.nc'))
+        >>> cube.coord('latitude').nearest_neighbour_index(0)
+        9
+        >>> cube.coord('longitude').nearest_neighbour_index(10)
+        12
+
         .. note:: If the coordinate contains bounds, these will be used to
             determine the nearest neighbour instead of the point values.
 
