@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -717,76 +717,86 @@ class FF2PP(object):
                 # read from the current FF LOOKUP table.
                 # (The PPField sub-class will depend on the header release
                 # number.)
-                field = pp.make_pp_field(header)
+                # (Some Fields File fields are UM specific scratch spaces, with
+                # no header release number, these will throw an exception from
+                # the PP module and are skipped to enable reading of the file.
+                try:
+                    field = pp.make_pp_field(header)
 
-                # Fast stash look-up.
-                stash_s = field.lbuser[3] // 1000
-                stash_i = field.lbuser[3] % 1000
-                stash = 'm{:02}s{:02}i{:03}'.format(field.lbuser[6],
-                                                    stash_s, stash_i)
-                stash_entry = STASH_TRANS.get(stash, None)
-                if stash_entry is None:
-                    subgrid = None
-                else:
-                    subgrid = stash_entry.grid_code
-                    if subgrid not in HANDLED_GRIDS:
-                        warnings.warn('The stash code {} is on a grid {} '
-                                      'which has not been explicitly handled '
-                                      'by the fieldsfile loader. Assuming the '
-                                      'data is on a P grid.'.format(stash,
-                                                                    subgrid))
-
-                field.x, field.y = grid.vectors(subgrid)
-
-                # Use the per-file grid if no per-field metadata is available.
-                no_x = field.bzx in (0, field.bmdi) and field.x is None
-                no_y = field.bzy in (0, field.bmdi) and field.y is None
-                if no_x and no_y:
-                    if subgrid is None:
-                        msg = ('The STASH code {0} was not found in the '
-                               'STASH to grid type mapping. Picking the P '
-                               'position as the cell type'.format(stash))
-                        warnings.warn(msg)
-                    field.bzx, field.bdx = grid.regular_x(subgrid)
-                    field.bzy, field.bdy = grid.regular_y(subgrid)
-                    field.bplat = grid.pole_lat
-                    field.bplon = grid.pole_lon
-                elif no_x or no_y:
-                    warnings.warn(
-                        'Partially missing X or Y coordinate values.')
-
-                # Check for LBC fields.
-                is_boundary_packed = self._ff_header.dataset_type == 5
-                if is_boundary_packed:
-                    # Apply adjustments specific to LBC data.
-                    self._adjust_field_for_lbc(field)
-
-                # Calculate start address of the associated PP header data.
-                data_offset = field.lbegin * self._word_depth
-                # Determine PP field payload depth and type.
-                data_depth, data_type = self._payload(field)
-
-                # Produce (yield) output fields.
-                if is_boundary_packed:
-                    fields = self._fields_over_all_levels(field)
-                else:
-                    fields = [field]
-                for result_field in fields:
-                    # Add a field data element.
-                    if self._read_data:
-                        # Read the actual bytes. This can then be converted to
-                        # a numpy array at a higher level.
-                        ff_file_seek(data_offset, os.SEEK_SET)
-                        result_field._data = pp.LoadedArrayBytes(
-                            ff_file.read(data_depth), data_type)
+                    # Fast stash look-up.
+                    stash_s = field.lbuser[3] // 1000
+                    stash_i = field.lbuser[3] % 1000
+                    stash = 'm{:02}s{:02}i{:03}'.format(field.lbuser[6],
+                                                        stash_s, stash_i)
+                    stash_entry = STASH_TRANS.get(stash, None)
+                    if stash_entry is None:
+                        subgrid = None
                     else:
-                        # Provide enough context to read the data bytes later.
-                        result_field._data = (self._filename, data_offset,
-                                              data_depth, data_type)
+                        subgrid = stash_entry.grid_code
+                        if subgrid not in HANDLED_GRIDS:
+                            warnings.warn('The stash code {} is on a grid {} '
+                                          'which has not been explicitly '
+                                          'handled by the fieldsfile loader.'
+                                          ' Assuming the data is on a P grid'
+                                          '.'.format(stash, subgrid))
 
-                    data_offset += data_depth
+                    field.x, field.y = grid.vectors(subgrid)
 
-                    yield result_field
+                    # Use the per-file grid if no per-field metadata is
+                    # available.
+                    no_x = field.bzx in (0, field.bmdi) and field.x is None
+                    no_y = field.bzy in (0, field.bmdi) and field.y is None
+                    if no_x and no_y:
+                        if subgrid is None:
+                            msg = ('The STASH code {0} was not found in the '
+                                   'STASH to grid type mapping. Picking the P '
+                                   'position as the cell type'.format(stash))
+                            warnings.warn(msg)
+                        field.bzx, field.bdx = grid.regular_x(subgrid)
+                        field.bzy, field.bdy = grid.regular_y(subgrid)
+                        field.bplat = grid.pole_lat
+                        field.bplon = grid.pole_lon
+                    elif no_x or no_y:
+                        warnings.warn(
+                            'Partially missing X or Y coordinate values.')
+
+                    # Check for LBC fields.
+                    is_boundary_packed = self._ff_header.dataset_type == 5
+                    if is_boundary_packed:
+                        # Apply adjustments specific to LBC data.
+                        self._adjust_field_for_lbc(field)
+
+                    # Calculate start address of the associated PP header data.
+                    data_offset = field.lbegin * self._word_depth
+                    # Determine PP field payload depth and type.
+                    data_depth, data_type = self._payload(field)
+
+                    # Produce (yield) output fields.
+                    if is_boundary_packed:
+                        fields = self._fields_over_all_levels(field)
+                    else:
+                        fields = [field]
+                    for result_field in fields:
+                        # Add a field data element.
+                        if self._read_data:
+                            # Read the actual bytes. This can then be converted
+                            # to a numpy array at a higher level.
+                            ff_file_seek(data_offset, os.SEEK_SET)
+                            result_field._data = pp.LoadedArrayBytes(
+                                ff_file.read(data_depth), data_type)
+                        else:
+                            # Provide enough context to read the data bytes
+                            # later.
+                            result_field._data = (self._filename, data_offset,
+                                                  data_depth, data_type)
+
+                        data_offset += data_depth
+
+                        yield result_field
+                except ValueError as valerr:
+                    msg = ('Input field skipped as PPField creation failed :'
+                           ' error = {!r}')
+                    warnings.warn(msg.format(str(valerr)))
 
     def __iter__(self):
         return pp._interpret_fields(self._extract_field())
