@@ -26,9 +26,11 @@ Version 1.4, 27 February 2009.
 
 from __future__ import (absolute_import, division, print_function)
 from six.moves import (filter, input, map, range, zip)  # noqa
+from six.moves import zip_longest  # Previous line may not be tampered with!
 import six
 
 import collections
+from itertools import repeat
 import os
 import os.path
 import re
@@ -525,7 +527,9 @@ def _load_cube(engine, cf, cf_var, filename):
     # Populate coordinate attributes with the untouched attributes from the
     # associated CF-netCDF variable.
     coordinates = engine.provides.get('coordinates', [])
-    attribute_predicate = lambda item: item[0] not in _CF_ATTRS
+
+    def attribute_predicate(item):
+        return item[0] not in _CF_ATTRS
 
     for coord, cf_var_name in coordinates:
         tmpvar = filter(attribute_predicate,
@@ -705,6 +709,34 @@ def load_cubes(filenames, callback=None):
             yield cube
 
 
+def _bytes_if_ascii(string):
+    """
+    Convert the given string to a byte string (str in py2k, bytes in py3k)
+    if the given string can be encoded to ascii, else maintain the type
+    of the inputted string.
+
+    Note: passing objects without an `encode` method (such as None) will
+    be returned by the function unchanged.
+
+    """
+    if isinstance(string, six.string_types):
+        try:
+            return string.encode(encoding='ascii')
+        except (AttributeError, UnicodeEncodeError):
+            pass
+    return string
+
+
+def _setncattr(variable, name, attribute):
+    """
+    Put the given attribute on the given netCDF4 Data type, casting
+    attributes as we go to bytes rather than unicode.
+
+    """
+    attribute = _bytes_if_ascii(attribute)
+    return variable.setncattr(name, attribute)
+
+
 class Saver(object):
     """A manager for saving netcdf files."""
 
@@ -776,7 +808,7 @@ class Saver(object):
     def write(self, cube, local_keys=None, unlimited_dimensions=None,
               zlib=False, complevel=4, shuffle=True, fletcher32=False,
               contiguous=False, chunksizes=None, endian='native',
-              least_significant_digit=None):
+              least_significant_digit=None, packing=None):
         """
         Wrapper for saving cubes to a NetCDF file.
 
@@ -855,6 +887,23 @@ class Saver(object):
             place in unpacked data that is a reliable value". Default is
             `None`, or no quantization, or 'lossless' compression.
 
+        * packing (type or string or dict or list): A numpy integer datatype
+            (signed or unsigned) or a string that describes a numpy integer
+            dtype(i.e. 'i2', 'short', 'u4') or a dict of packing parameters as
+            described below. This provides support for netCDF data packing as
+            described in
+            http://www.unidata.ucar.edu/software/netcdf/docs/BestPractices.html#bp_Packed-Data-Values
+            If this argument is a type (or type string), appropriate values of
+            scale_factor and add_offset will be automatically calculated based
+            on `cube.data` and possible masking. For masked data, `fill_value`
+            is taken from netCDF4.default_fillvals. For more control, pass a
+            dict with one or more of the following keys: `dtype` (required),
+            `scale_factor`, `add_offset`, and `fill_value`. Note that automatic
+            calculation of packing parameters will trigger loading of lazy
+            data; set them manually using a dict to avoid this. The default is
+            `None`, in which case the datatype is determined from the cube and
+            no packing will occur.
+
         Returns:
             None.
 
@@ -902,7 +951,7 @@ class Saver(object):
             cube, dimension_names, local_keys, zlib=zlib, complevel=complevel,
             shuffle=shuffle, fletcher32=fletcher32, contiguous=contiguous,
             chunksizes=chunksizes, endian=endian,
-            least_significant_digit=least_significant_digit)
+            least_significant_digit=least_significant_digit, packing=packing)
 
         # Add coordinate variables.
         self._add_dim_coords(cube, dimension_names)
@@ -990,10 +1039,10 @@ class Saver(object):
                 attributes = dict(attributes)
 
             for attr_name in sorted(attributes):
-                self._dataset.setncattr(attr_name, attributes[attr_name])
+                _setncattr(self._dataset, attr_name, attributes[attr_name])
 
         for attr_name in sorted(kwargs):
-            self._dataset.setncattr(attr_name, kwargs[attr_name])
+            _setncattr(self._dataset, attr_name, kwargs[attr_name])
 
     def _create_cf_dimensions(self, cube, dimension_names,
                               unlimited_dimensions=None):
@@ -1072,8 +1121,8 @@ class Saver(object):
         # Add CF-netCDF auxiliary coordinate variable references to the
         # CF-netCDF data variable.
         if auxiliary_coordinate_names:
-            cf_var_cube.coordinates = ' '.join(
-                sorted(auxiliary_coordinate_names))
+            coord_variable_names = ' '.join(sorted(auxiliary_coordinate_names))
+            _setncattr(cf_var_cube, 'coordinates', coord_variable_names)
 
     def _add_cell_measures(self, cube, cf_var_cube, dim_names):
         """
@@ -1107,8 +1156,8 @@ class Saver(object):
         # Add CF-netCDF cell measure variable references to the
         # CF-netCDF data variable.
         if cell_measure_names:
-            cf_var_cube.cell_measures = ' '.join(
-                sorted(cell_measure_names))
+            cm_var_names = ' '.join(sorted(cell_measure_names))
+            _setncattr(cf_var_cube, 'cell_measures', cm_var_names)
 
     def _add_dim_coords(self, cube, dimension_names):
         """
@@ -1196,22 +1245,23 @@ class Saver(object):
                                                             dimension_names,
                                                             primary_coord)
                             cf_var = self._dataset.variables[name]
-                            cf_var.standard_name = std_name
-                            cf_var.axis = 'Z'
+                            _setncattr(cf_var, 'standard_name', std_name)
+                            _setncattr(cf_var, 'axis', 'Z')
                             # Update the formula terms.
                             ft = formula_terms.split()
                             ft = [name if t == cf_name else t for t in ft]
-                            cf_var.formula_terms = ' '.join(ft)
+                            _setncattr(cf_var, 'formula_terms', ' '.join(ft))
                             # Update the cache.
                             self._formula_terms_cache[key] = name
                         # Update the associated cube variable.
                         coords = cf_var_cube.coordinates.split()
                         coords = [name if c == cf_name else c for c in coords]
-                        cf_var_cube.coordinates = ' '.join(coords)
+                        _setncattr(cf_var_cube, 'coordinates',
+                                   ' '.join(coords))
                 else:
-                    cf_var.standard_name = std_name
-                    cf_var.axis = 'Z'
-                    cf_var.formula_terms = formula_terms
+                    _setncattr(cf_var, 'standard_name', std_name)
+                    _setncattr(cf_var, 'axis', 'Z')
+                    _setncattr(cf_var, 'formula_terms', formula_terms)
 
     def _get_dim_names(self, cube):
         """
@@ -1272,7 +1322,8 @@ class Saver(object):
                 dimension_names.append(dim_name)
         return dimension_names
 
-    def _cf_coord_identity(self, coord):
+    @staticmethod
+    def _cf_coord_identity(coord):
         """
         Determine a suitable units from a given coordinate.
 
@@ -1353,7 +1404,7 @@ class Saver(object):
                 # Create the bounds dimension with the appropriate extent.
                 self._dataset.createDimension(bounds_dimension_name, n_bounds)
 
-            cf_var.bounds = cf_name + '_bnds'
+            _setncattr(cf_var, 'bounds', cf_name + '_bnds')
             cf_var_bounds = self._dataset.createVariable(
                 cf_var.bounds, bounds.dtype.newbyteorder('='),
                 cf_var.dimensions + (bounds_dimension_name,))
@@ -1411,7 +1462,6 @@ class Saver(object):
                     name = 'unknown_scalar'
             # Convert to lower case and replace whitespace by underscores.
             cf_name = '_'.join(name.lower().split())
-
         return cf_name
 
     def _create_cf_cell_measure_variable(self, cube, dimension_names,
@@ -1453,13 +1503,13 @@ class Saver(object):
         cf_var[:] = data
 
         if cell_measure.units != 'unknown':
-            cf_var.units = str(cell_measure.units)
+            _setncattr(cf_var, 'units', str(cell_measure.units))
 
         if cell_measure.standard_name is not None:
-            cf_var.standard_name = cell_measure.standard_name
+            _setncattr(cf_var, 'standard_name', cell_measure.standard_name)
 
         if cell_measure.long_name is not None:
-            cf_var.long_name = cell_measure.long_name
+            _setncattr(cf_var, 'long_name', cell_measure.long_name)
 
         # Add any other custom coordinate attributes.
         for name in sorted(cell_measure.attributes):
@@ -1467,7 +1517,7 @@ class Saver(object):
 
             # Don't clobber existing attributes.
             if not hasattr(cf_var, name):
-                cf_var.setncattr(name, value)
+                _setncattr(cf_var, name, value)
 
         return cf_name
 
@@ -1549,7 +1599,7 @@ class Saver(object):
             if coord in cf_coordinates:
                 axis = iris.util.guess_coord_axis(coord)
                 if axis is not None and axis.lower() in SPATIO_TEMPORAL_AXES:
-                    cf_var.axis = axis.upper()
+                    _setncattr(cf_var, 'axis', axis.upper())
 
             # Add the data to the CF-netCDF variable.
             cf_var[:] = points
@@ -1561,17 +1611,17 @@ class Saver(object):
         standard_name, long_name, units = self._cf_coord_identity(coord)
 
         if units != 'unknown':
-            cf_var.units = units
+            _setncattr(cf_var, 'units', units)
 
         if standard_name is not None:
-            cf_var.standard_name = standard_name
+            _setncattr(cf_var, 'standard_name', standard_name)
 
         if long_name is not None:
-            cf_var.long_name = long_name
+            _setncattr(cf_var, 'long_name', long_name)
 
         # Add the CF-netCDF calendar attribute.
         if coord.units.calendar:
-            cf_var.calendar = coord.units.calendar
+            _setncattr(cf_var, 'calendar', coord.units.calendar)
 
         # Add any other custom coordinate attributes.
         for name in sorted(coord.attributes):
@@ -1585,7 +1635,7 @@ class Saver(object):
 
             # Don't clobber existing attributes.
             if not hasattr(cf_var, name):
-                cf_var.setncattr(name, value)
+                _setncattr(cf_var, name, value)
 
         return cf_name
 
@@ -1661,12 +1711,13 @@ class Saver(object):
             # Grid var not yet created?
             if cs not in self._coord_systems:
                 while cs.grid_mapping_name in self._dataset.variables:
-                    cs.grid_mapping_name = (
-                        self._increment_name(cs.grid_mapping_name))
+                    aname = self._increment_name(cs.grid_mapping_name)
+                    cs.grid_mapping_name = aname
 
                 cf_var_grid = self._dataset.createVariable(
                     cs.grid_mapping_name, np.int32)
-                cf_var_grid.grid_mapping_name = cs.grid_mapping_name
+                _setncattr(cf_var_grid, 'grid_mapping_name',
+                           cs.grid_mapping_name)
 
                 def add_ellipsoid(ellipsoid):
                     cf_var_grid.longitude_of_prime_meridian = (
@@ -1752,6 +1803,18 @@ class Saver(object):
                 elif isinstance(cs, iris.coord_systems.OSGB):
                     warnings.warn('OSGB coordinate system not yet handled')
 
+                # lambert azimuthal equal area
+                elif isinstance(cs,
+                                iris.coord_systems.LambertAzimuthalEqualArea):
+                    if cs.ellipsoid:
+                        add_ellipsoid(cs.ellipsoid)
+                    cf_var_grid.longitude_of_projection_origin = (
+                        cs.longitude_of_projection_origin)
+                    cf_var_grid.latitude_of_projection_origin = (
+                        cs.latitude_of_projection_origin)
+                    cf_var_grid.false_easting = cs.false_easting
+                    cf_var_grid.false_northing = cs.false_northing
+
                 # other
                 else:
                     warnings.warn('Unable to represent the horizontal '
@@ -1761,7 +1824,7 @@ class Saver(object):
                 self._coord_systems.append(cs)
 
             # Refer to grid var
-            cf_var_cube.grid_mapping = cs.grid_mapping_name
+            _setncattr(cf_var_cube, 'grid_mapping', cs.grid_mapping_name)
 
     def _create_cf_data_variable(self, cube, dimension_names, local_keys=None,
                                  **kwargs):
@@ -1789,47 +1852,109 @@ class Saver(object):
             The newly created CF-netCDF data variable.
 
         """
+        if 'packing' in kwargs:
+            packing = kwargs.pop('packing')
+            if packing:
+                scale_factor = None
+                add_offset = None
+                fill_value = None
+                if isinstance(packing, dict):
+                    if 'dtype' not in packing:
+                        msg = "The dtype attribute is required for packing."
+                        raise ValueError(msg)
+                    dtype = np.dtype(packing['dtype'])
+                    if 'scale_factor' in packing:
+                        scale_factor = packing['scale_factor']
+                    if 'add_offset' in packing:
+                        add_offset = packing['add_offset']
+                    if 'fill_value' in packing:
+                        fill_value = packing['fill_value']
+                else:
+                    masked = ma.isMaskedArray(cube.data)
+                    dtype = np.dtype(packing)
+                    cmax = cube.data.max()
+                    cmin = cube.data.min()
+                    n = dtype.itemsize * 8
+                    if masked:
+                        scale_factor = (cmax - cmin)/(2**n-2)
+                    else:
+                        scale_factor = (cmax - cmin)/(2**n-1)
+                    if dtype.kind == 'u':
+                        add_offset = cmin
+                    elif dtype.kind == 'i':
+                        if masked:
+                            add_offset = (cmax + cmin)/2
+                        else:
+                            add_offset = cmin + 2**(n-1)*scale_factor
+                needs_fill_value = (cube.has_lazy_data() or
+                                    ma.isMaskedArray(cube.data))
+                if needs_fill_value and fill_value is None:
+                    dtstr = dtype.str[1:]
+                    fill_value = netCDF4.default_fillvals[dtstr]
+        else:
+            packing = None
+
+        def set_packing_ncattrs(cfvar):
+            """Set netCDF packing attributes."""
+            if packing:
+                if scale_factor:
+                    _setncattr(cfvar, 'scale_factor', scale_factor)
+                if add_offset:
+                    _setncattr(cfvar, 'add_offset', add_offset)
+
         cf_name = self._get_cube_variable_name(cube)
         while cf_name in self._dataset.variables:
             cf_name = self._increment_name(cf_name)
 
         # if netcdf3 avoid streaming due to dtype handling
-        if (not cube.has_lazy_data()
-                or self._dataset.file_format in ('NETCDF3_CLASSIC',
-                                                 'NETCDF3_64BIT')):
-            # Determine whether there is a cube MDI value.
-            fill_value = None
-            if isinstance(cube.data, ma.core.MaskedArray):
-                fill_value = cube.data.fill_value
+        if (not cube.has_lazy_data() or
+            self._dataset.file_format in ('NETCDF3_CLASSIC',
+                                          'NETCDF3_64BIT')):
+
+            if packing is None:
+                # Determine whether there is a cube MDI value.
+                if ma.isMaskedArray(cube.data):
+                    fill_value = cube.data.fill_value
+                else:
+                    fill_value = None
 
             # Get the values in a form which is valid for the file format.
             data = self._ensure_valid_dtype(cube.data, 'cube', cube)
 
+            if packing is None:
+                dtype = data.dtype.newbyteorder('=')
+
             # Create the cube CF-netCDF data variable with data payload.
             cf_var = self._dataset.createVariable(
-                cf_name, data.dtype.newbyteorder('='), dimension_names,
+                cf_name, dtype, dimension_names,
                 fill_value=fill_value, **kwargs)
+            set_packing_ncattrs(cf_var)
             cf_var[:] = data
 
         else:
             # Create the cube CF-netCDF data variable.
             # Explicitly assign the fill_value, which will be the type default
             # in the case of an unmasked array.
+            if packing is None:
+                fill_value = cube.lazy_data().fill_value
+                dtype = cube.lazy_data().dtype.newbyteorder('=')
+
             cf_var = self._dataset.createVariable(
-                cf_name, cube.lazy_data().dtype.newbyteorder('='),
-                dimension_names, fill_value=cube.lazy_data().fill_value,
+                cf_name, dtype,
+                dimension_names, fill_value=fill_value,
                 **kwargs)
+            set_packing_ncattrs(cf_var)
             # stream the data
             biggus.save([cube.lazy_data()], [cf_var], masked=True)
 
         if cube.standard_name:
-            cf_var.standard_name = cube.standard_name
+            _setncattr(cf_var, 'standard_name', cube.standard_name)
 
         if cube.long_name:
-            cf_var.long_name = cube.long_name
+            _setncattr(cf_var, 'long_name', cube.long_name)
 
         if cube.units != 'unknown':
-            cf_var.units = str(cube.units)
+            _setncattr(cf_var, 'units', str(cube.units))
 
         # Add data variable-only attribute names to local_keys.
         if local_keys is None:
@@ -1863,13 +1988,13 @@ class Saver(object):
                       'global attribute.'.format(attr_name=attr_name)
                 warnings.warn(msg)
 
-            cf_var.setncattr(attr_name, value)
+            _setncattr(cf_var, attr_name, value)
 
         # Create the CF-netCDF data variable cell method attribute.
         cell_methods = self._create_cf_cell_methods(cube, dimension_names)
 
         if cell_methods:
-            cf_var.cell_methods = cell_methods
+            _setncattr(cf_var, 'cell_methods', cell_methods)
 
         # Create the CF-netCDF grid mapping.
         self._create_cf_grid_mapping(cube, cf_var)
@@ -1907,7 +2032,7 @@ class Saver(object):
 def save(cube, filename, netcdf_format='NETCDF4', local_keys=None,
          unlimited_dimensions=None, zlib=False, complevel=4, shuffle=True,
          fletcher32=False, contiguous=False, chunksizes=None, endian='native',
-         least_significant_digit=None):
+         least_significant_digit=None, packing=None):
     """
     Save cube(s) to a netCDF file, given the cube and the filename.
 
@@ -2004,6 +2129,24 @@ def save(cube, filename, netcdf_format='NETCDF4', local_keys=None,
         in unpacked data that is a reliable value". Default is `None`, or no
         quantization, or 'lossless' compression.
 
+    * packing (type or string or dict or list): A numpy integer datatype
+        (signed or unsigned) or a string that describes a numpy integer dtype
+        (i.e. 'i2', 'short', 'u4') or a dict of packing parameters as described
+        below or an iterable of such types, strings, or dicts.
+        This provides support for netCDF data packing as described in
+        http://www.unidata.ucar.edu/software/netcdf/docs/BestPractices.html#bp_Packed-Data-Values
+        If this argument is a type (or type string), appropriate values of
+        scale_factor and add_offset will be automatically calculated based on
+        `cube.data` and possible masking. For masked data, `fill_value` is
+        taken from netCDF4.default_fillvals. For more control, pass a dict with
+        one or more of the following keys: `dtype` (required), `scale_factor`,
+        `add_offset`, and `fill_value`. To save multiple cubes with different
+        packing parameters, pass an iterable of types, strings, dicts, or
+        `None`, one for each cube.  Note that automatic calculation of packing
+        parameters will trigger loading of lazy data; set them manually using a
+        dict to avoid this. The default is `None`, in which case the datatype
+        is determined from the cube and no packing will occur.
+
     Returns:
         None.
 
@@ -2058,13 +2201,48 @@ def save(cube, filename, netcdf_format='NETCDF4', local_keys=None,
         common_keys.difference_update(different_value_keys)
         local_keys.update(different_value_keys)
 
+    def is_valid_packspec(p):
+        """ Only checks that the datatype is valid. """
+        if isinstance(p, dict):
+            if 'dtype' in p:
+                return is_valid_packspec(p['dtype'])
+            else:
+                msg = "The argument to packing must contain the key 'dtype'."
+                raise ValueError(msg)
+        elif (isinstance(p, six.text_type) or isinstance(p, type) or
+              isinstance(p, str)):
+            pdtype = np.dtype(p)  # Does nothing if it's already a numpy dtype
+            if pdtype.kind != 'i' and pdtype.kind != 'u':
+                msg = "The packing datatype must be a numpy integer type."
+                raise ValueError(msg)
+            return True
+        elif p is None:
+            return True
+        else:
+            return False
+
+    if is_valid_packspec(packing):
+        packspecs = repeat(packing)
+    else:
+        # Assume iterable, make sure packing is the same length as cubes.
+        for cube, packspec in zip_longest(cubes, packing, fillvalue=-1):
+            if cube == -1 or packspec == -1:
+                msg = ('If packing is a list, it must have the '
+                       'same number of elements as the argument to'
+                       'cube.')
+                raise ValueError(msg)
+            if not is_valid_packspec(packspec):
+                msg = ('Invalid packing argument: {}.'.format(packspec))
+                raise ValueError(msg)
+        packspecs = packing
+
     # Initialise Manager for saving
     with Saver(filename, netcdf_format) as sman:
         # Iterate through the cubelist.
-        for cube in cubes:
+        for cube, packspec in zip(cubes, packspecs):
             sman.write(cube, local_keys, unlimited_dimensions, zlib, complevel,
                        shuffle, fletcher32, contiguous, chunksizes, endian,
-                       least_significant_digit)
+                       least_significant_digit, packing=packspec)
 
         conventions = CF_CONVENTIONS_VERSION
 
