@@ -1950,10 +1950,12 @@ def _field_gen(filename, read_data_bytes, little_ended=False):
                 '%cL' % dtype_endian_char,
                 pp_file_read(PP_WORD_DEPTH))[0]
             if len_of_data_plus_extra != pp_field.lblrec * PP_WORD_DEPTH:
-                raise ValueError('LBLREC has a different value to the integer '
-                                 'recorded after the header in the file (%s '
-                                 'and %s).' % (pp_field.lblrec * PP_WORD_DEPTH,
-                                               len_of_data_plus_extra))
+                wmsg = ('LBLREC has a different value to the integer recorded '
+                        'after the header in the file ({} and {}). '
+                        'Skipping the remainder of the file.')
+                warnings.warn(wmsg.format(pp_field.lblrec * PP_WORD_DEPTH,
+                                          len_of_data_plus_extra))
+                break
 
             # calculate the extra length in bytes
             extra_len = pp_field.lbext * PP_WORD_DEPTH
@@ -2030,16 +2032,16 @@ def add_save_rules(filename):
     .. deprecated:: 1.10
 
         If you need to customise pp field saving, please refer to the functions
-        :func:`as_fields`, :func:`as_pairs` and :func:`save_fields` for an
-        alternative solution.
+        :func:`as_fields`, :func:`save_pairs_from_cube` and :func:`save_fields`
+        for an alternative solution.
 
     """
     warn_deprecated(
         'custom pp save rules are deprecated from v1.10.\n'
         'If you need to customise pp field saving, please refer to the '
         'functions iris.fileformats.pp.as_fields, '
-        'iris.fileformats.pp.as_pairs and iris.fileformats.pp.save_fields '
-        'for an alternative solution.')
+        'iris.fileformats.pp.save_pairs_from_cube and '
+        'iris.fileformats.pp.save_fields for an alternative solution.')
     _ensure_save_rules_loaded()
     _save_rules.import_rules(filename)
 
@@ -2051,16 +2053,16 @@ def reset_save_rules():
     .. deprecated:: 1.10
 
         If you need to customise pp field saving, please refer to the functions
-        :func:`as_fields`, :func:`as_pairs` and :func:`save_fields` for an
-        alternative solution.
+        :func:`as_fields`, :func:`save_pairs_from_cube` and :func:`save_fields`
+        for an alternative solution.
 
     """
     warn_deprecated(
         'custom pp save rules are deprecated from v1.10.\n'
         'If you need to customise pp field saving, please refer to the '
         'functions iris.fileformats.pp.as_fields, '
-        'iris.fileformats.pp.as_pairs and iris.fileformats.pp.save_fields '
-        'for an alternative solution.')
+        'iris.fileformats.pp.save_pairs_from_cube and '
+        'iris.fileformats.pp.save_fields for an alternative solution.')
     # Uses this module-level variable
     global _save_rules
 
@@ -2241,14 +2243,39 @@ def load_pairs_from_fields(pp_fields):
 def _load_cubes_variable_loader(filenames, callback, loading_function,
                                 loading_function_kwargs=None,
                                 constraints=None):
+    import iris.fileformats.um._fast_load as um_fast_load
     pp_filter = None
     if constraints is not None:
         pp_filter = _convert_constraints(constraints)
-    pp_loader = iris.fileformats.rules.Loader(
-        loading_function, loading_function_kwargs or {},
-        iris.fileformats.pp_rules.convert)
-    return iris.fileformats.rules.load_cubes(filenames, callback, pp_loader,
-                                             pp_filter)
+    if um_fast_load.STRUCTURED_LOAD_CONTROLS.loads_use_structured:
+        # For structured loads, pass down the pp_filter function as an extra
+        # keyword to the low-level generator function.
+        loading_function_kwargs = loading_function_kwargs or {}
+        loading_function_kwargs['pp_filter'] = pp_filter
+        # Also do *not* use this filter in generic rules processing, as for
+        # structured loading, the 'field' of rules processing is no longer a
+        # PPField but a FieldCollation.
+        pp_filter = None
+        # Make a loader object for the generic rules code.
+        loader = iris.fileformats.rules.Loader(
+            um_fast_load._basic_load_function,
+            loading_function_kwargs,
+            um_fast_load._convert_collation)
+    else:
+        loader = iris.fileformats.rules.Loader(
+            loading_function, loading_function_kwargs or {},
+            iris.fileformats.pp_rules.convert)
+
+    result = iris.fileformats.rules.load_cubes(filenames, callback, loader,
+                                               pp_filter)
+
+    if um_fast_load.STRUCTURED_LOAD_CONTROLS.loads_use_structured:
+        # We need an additional concatenate-like operation to combine cubes
+        # from different files.  Unfortunately, the 'merge' call provided in
+        # the iris_load_xx functions cannot do this.
+        result = um_fast_load._combine_structured_cubes(result)
+
+    return result
 
 
 def save(cube, target, append=False, field_coords=None):
