@@ -41,6 +41,7 @@ import iris.analysis
 import iris.coords
 import iris.cube
 import iris.fileformats
+import iris.fileformats.dot
 import iris.tests.pp as pp
 import iris.tests.stock
 
@@ -214,6 +215,7 @@ class TestBasicCubeConstruction(tests.IrisTest):
             dims[0] = 1
 
 
+@tests.skip_data
 class TestStockCubeStringRepresentations(tests.IrisTest):
     def setUp(self):
         self.cube = iris.tests.stock.realistic_4d()
@@ -276,10 +278,12 @@ class TestCubeStringRepresentations(IrisDotTest):
         del cube.attributes['my_attribute']
        
     # TODO hybrid height and dot output - relatitionship links
+    @tests.skip_data
     def test_dot_4d(self):
         cube = iris.tests.stock.realistic_4d()
         self.check_dot(cube, ('file_load', '4d_pp.dot'))
 
+    @tests.skip_data
     def test_missing_coords(self):
         cube = iris.tests.stock.realistic_4d()
         cube.remove_coord('time')
@@ -289,6 +293,7 @@ class TestCubeStringRepresentations(IrisDotTest):
         self.assertString(str(cube),
                           ('cdm', 'str_repr', 'missing_coords_cube.str.txt'))
 
+    @tests.skip_data
     def test_cubelist_string(self):
         cube_list = iris.cube.CubeList([iris.tests.stock.realistic_4d(),
                                         iris.tests.stock.global_pp()])
@@ -1038,39 +1043,66 @@ class TestCubeCollapsed(tests.IrisTest):
 
         self.assertCML(cube, ('cube_collapsed', 'original.cml'))
 
-        # Compare 2-stage collapsing with a single stage collapse over 2 Coords.
-        self.collapse_test_common(cube, 'grid_latitude', 'grid_longitude', decimal=1)
-        self.collapse_test_common(cube, 'grid_longitude', 'grid_latitude', decimal=1)
+        # Compare 2-stage collapsing with a single stage collapse
+        # over 2 Coords.
+        self.collapse_test_common(cube, 'grid_latitude', 'grid_longitude',
+                                  rtol=1e-05)
+        self.collapse_test_common(cube, 'grid_longitude', 'grid_latitude',
+                                  rtol=1e-05)
 
-        self.collapse_test_common(cube, 'time', 'grid_latitude', decimal=1)
-        self.collapse_test_common(cube, 'grid_latitude', 'time', decimal=1)
+        self.collapse_test_common(cube, 'time', 'grid_latitude', rtol=1e-05)
+        self.collapse_test_common(cube, 'grid_latitude', 'time', rtol=1e-05)
 
-        self.collapse_test_common(cube, 'time', 'grid_longitude', decimal=1)
-        self.collapse_test_common(cube, 'grid_longitude', 'time', decimal=1)
+        self.collapse_test_common(cube, 'time', 'grid_longitude', rtol=1e-05)
+        self.collapse_test_common(cube, 'grid_longitude', 'time', rtol=1e-05)
 
-        self.collapse_test_common(cube, 'grid_latitude', 'model_level_number', decimal=1)
-        self.collapse_test_common(cube, 'model_level_number', 'grid_latitude', decimal=1)
+        self.collapse_test_common(cube, 'grid_latitude', 'model_level_number',
+                                  rtol=5e-04)
+        self.collapse_test_common(cube, 'model_level_number', 'grid_latitude',
+                                  rtol=5e-04)
 
-        self.collapse_test_common(cube, 'grid_longitude', 'model_level_number', decimal=1)
-        self.collapse_test_common(cube, 'model_level_number', 'grid_longitude', decimal=1)
+        self.collapse_test_common(cube, 'grid_longitude', 'model_level_number',
+                                  rtol=5e-04)
+        self.collapse_test_common(cube, 'model_level_number', 'grid_longitude',
+                                  rtol=5e-04)
 
-        self.collapse_test_common(cube, 'time', 'model_level_number', decimal=1)
-        self.collapse_test_common(cube, 'model_level_number', 'time', decimal=1)
+        self.collapse_test_common(cube, 'time', 'model_level_number',
+                                  rtol=5e-04)
+        self.collapse_test_common(cube, 'model_level_number', 'time',
+                                  rtol=5e-04)
 
-        self.collapse_test_common(cube, 'model_level_number', 'time', decimal=1)
-        self.collapse_test_common(cube, 'time', 'model_level_number', decimal=1)
+        self.collapse_test_common(cube, 'model_level_number', 'time',
+                                  rtol=5e-04)
+        self.collapse_test_common(cube, 'time', 'model_level_number',
+                                  rtol=5e-04)
 
         # Collapse 3 things at once.
-        triple_collapse = cube.collapsed(['model_level_number', 'time', 'grid_longitude'], iris.analysis.MEAN)
-        self.assertCMLApproxData(triple_collapse, ('cube_collapsed', 'triple_collapse_ml_pt_lon.cml'), decimal=1)
+        triple_collapse = cube.collapsed(['model_level_number',
+                                          'time', 'grid_longitude'],
+                                          iris.analysis.MEAN)
+        self.assertCMLApproxData(triple_collapse, ('cube_collapsed',
+                                                   ('triple_collapse_ml_pt_'
+                                                    'lon.cml')),
+                                                   rtol=5e-04)
 
-        triple_collapse = cube.collapsed(['grid_latitude', 'model_level_number', 'time'], iris.analysis.MEAN)
-        self.assertCMLApproxData(triple_collapse, ('cube_collapsed', 'triple_collapse_lat_ml_pt.cml'), decimal=1)
+        triple_collapse = cube.collapsed(['grid_latitude',
+                                          'model_level_number', 'time'],
+                                          iris.analysis.MEAN)
+        self.assertCMLApproxData(triple_collapse, ('cube_collapsed',
+                                                   ('triple_collapse_lat_ml'
+                                                   '_pt.cml')),
+                                                   rtol=0.05)
+        # KNOWN PROBLEM: the previous 'rtol' is very large.
+        # Numpy 1.10 and 1.11 give significantly different results here.
+        # This may relate to known problems with summing over large arrays,
+        # which were largely fixed in numpy 1.9 but still occur in some cases,
+        # as-of numpy 1.11.
 
         # Ensure no side effects
         self.assertCML(cube, ('cube_collapsed', 'original.cml'))
-        
-        
+
+
+@tests.skip_data
 class TestTrimAttributes(tests.IrisTest):
     def test_non_string_attributes(self):
         cube = iris.tests.stock.realistic_4d()
@@ -1155,6 +1187,7 @@ class TestMaskedData(tests.IrisTest, pp.PPTest):
             self.assertEqual(merged_cube.data.fill_value, 123456)
 
 
+@tests.skip_data
 class TestConversionToCoordList(tests.IrisTest):
     def test_coord_conversion(self):
         cube = iris.tests.stock.realistic_4d()
