@@ -80,7 +80,6 @@ class StandardReportWithExclusions(pep8.StandardReport):
     expected_bad_files = [
         '*/iris/std_names.py',
         '*/iris/analysis/_interpolate_private.py',
-        '*/iris/analysis/trajectory.py',
         '*/iris/fileformats/cf.py',
         '*/iris/fileformats/dot.py',
         '*/iris/fileformats/grib/__init__.py',
@@ -128,7 +127,6 @@ class StandardReportWithExclusions(pep8.StandardReport):
         '*/iris/tests/test_quickplot.py',
         '*/iris/tests/test_regrid.py',
         '*/iris/tests/test_std_names.py',
-        '*/iris/tests/test_trajectory.py',
         '*/iris/tests/test_unit.py',
         '*/iris/tests/test_uri_callback.py',
         '*/iris/tests/test_util.py']
