@@ -1409,5 +1409,22 @@ class TestCellMeasures(tests.IrisTest):
             cm_dims = self.cube.cell_measure_dims(a_cell_measure)
 
 
+class Test_transpose(tests.IrisTest):
+    def test_lazy_data(self):
+        data = np.arange(12).reshape(3, 4)
+        cube = Cube(biggus.NumpyArrayAdapter(data))
+        cube.transpose()
+        self.assertTrue(cube.has_lazy_data())
+        self.assertArrayEqual(data.T, cube.data)
+
+    def test_not_lazy_data(self):
+        data = np.arange(12).reshape(3, 4)
+        cube = Cube(data)
+        cube.transpose()
+        self.assertFalse(cube.has_lazy_data())
+        self.assertIs(data.base, cube.data.base)
+        self.assertArrayEqual(data.T, cube.data)
+
+
 if __name__ == '__main__':
     tests.main()
