@@ -1871,8 +1871,7 @@ class Unit(iris.util._OrderedHashable):
                 ut2 = other.utime()
                 result = ut2.date2num(ut1.num2date(value_copy))
                 # Preserve the datatype of the input array if it was float32.
-                if (isinstance(value, np.ndarray)
-                        and value.dtype == np.float32):
+                if isinstance(value, np.ndarray) and value.dtype == np.float32:
                     result = result.astype(np.float32)
             else:
                 ut_converter = _ut_get_converter(self.ut_unit, other.ut_unit)
@@ -1932,16 +1931,6 @@ class Unit(iris.util._OrderedHashable):
 
         Returns:
             netcdftime.utime.
-
-        For example:
-
-            >>> import cf_units as unit
-            >>> u = unit.Unit('hours since 1970-01-01 00:00:00',
-            ...               calendar=unit.CALENDAR_STANDARD)
-            >>> ut = u.utime()
-            >>> ut.num2date(2)
-            datetime.datetime(1970, 1, 1, 2, 0)
-
         """
 
         #
@@ -1972,19 +1961,6 @@ class Unit(iris.util._OrderedHashable):
 
         Returns:
             float or numpy.ndarray of float.
-
-        For example:
-
-            >>> import cf_units as unit
-            >>> import datetime
-            >>> u = unit.Unit('hours since 1970-01-01 00:00:00',
-            ...               calendar=unit.CALENDAR_STANDARD)
-            >>> u.date2num(datetime.datetime(1970, 1, 1, 5))
-            5.00000000372529
-            >>> u.date2num([datetime.datetime(1970, 1, 1, 5),
-            ...             datetime.datetime(1970, 1, 1, 6)])
-            array([ 5.,  6.])
-
         """
 
         cdf_utime = self.utime()
@@ -2016,18 +1992,6 @@ class Unit(iris.util._OrderedHashable):
 
         Returns:
             datetime, or numpy.ndarray of datetime object.
-
-        For example:
-
-            >>> import cf_units as unit
-            >>> u = unit.Unit('hours since 1970-01-01 00:00:00',
-            ...               calendar=unit.CALENDAR_STANDARD)
-            >>> u.num2date(6)
-            datetime.datetime(1970, 1, 1, 6, 0)
-            >>> u.num2date([6, 7])
-            array([datetime.datetime(1970, 1, 1, 6, 0),
-                   datetime.datetime(1970, 1, 1, 7, 0)], dtype=object)
-
         """
         cdf_utime = self.utime()
         return cdf_utime.num2date(time_value)
