@@ -306,8 +306,8 @@ def guess_coord_axis(coord):
     elif coord.standard_name in ('latitude', 'grid_latitude',
                                  'projection_y_coordinate'):
         axis = 'Y'
-    elif (coord.units.is_convertible('hPa')
-          or coord.attributes.get('positive') in ('up', 'down')):
+    elif (coord.units.is_convertible('hPa') or
+          coord.attributes.get('positive') in ('up', 'down')):
         axis = 'Z'
     elif coord.units.is_time_reference():
         axis = 'T'
@@ -598,8 +598,9 @@ def column_slices_generator(full_slice, ndims):
 
     # Get all of the dimensions for which a tuple of indices were provided
     # (numpy.ndarrays are treated in the same way tuples in this case)
-    is_tuple_style_index = lambda key: isinstance(key, tuple) or \
-        (isinstance(key, np.ndarray) and key.ndim == 1)
+    def is_tuple_style_index(key):
+        return (isinstance(key, tuple) or
+                (isinstance(key, np.ndarray) and key.ndim == 1))
     tuple_indices = [i for i, key in enumerate(full_slice)
                      if is_tuple_style_index(key)]
 
@@ -1082,7 +1083,16 @@ def new_axis(src_cube, scalar_coord=None):
 
     # Indexing numpy arrays requires loading deferred data here returning a
     # copy of the data with a new leading dimension.
-    new_cube = iris.cube.Cube(src_cube.lazy_data()[None])
+    # If the source cube is a Masked Constant, it is changed here to a Masked
+    # Array to allow the mask to gain an extra dimension with the data.
+    if src_cube.has_lazy_data():
+        new_cube = iris.cube.Cube(src_cube.lazy_data()[None])
+    else:
+        if isinstance(src_cube.data, ma.core.MaskedConstant):
+            new_data = ma.array([np.nan], mask=[True])
+        else:
+            new_data = src_cube.data[None]
+        new_cube = iris.cube.Cube(new_data)
     new_cube.metadata = src_cube.metadata
 
     for coord in src_cube.aux_coords:
@@ -1398,7 +1408,7 @@ def _is_circular(points, modulus, bounds=None):
         if len(points) > 1:
             diffs = list(set(np.diff(points)))
             diff = np.mean(diffs)
-            abs_tol = diff * 1.0e-4
+            abs_tol = np.abs(diff * 1.0e-4)
             diff_approx_equal = np.max(np.abs(diffs - diff)) < abs_tol
             if diff_approx_equal:
                 circular_value = (points[-1] + diff) % modulus
